---
name: Usability Issue/Improvement
about: '"UX work to be done"'
title: ''
labels: ux
assignees: ''

---

### Background
_Context, goals, known challenges, technical risks, unknowns, etc_

### User needs statement(s)
As a _[type of user]_, I need/want to _[action(s)]_, so that I can _[goal]_.

### Size
_Expected level of user research, discovery and design effort (xs, sm, m, lg, xl)_

### Requirements
_Examples:_
- _UI for ability to add, edit, and save_
- _Error messaging for error states_
- _Solution for responsive design on small screen sizes_
- _Align new feature to exising style_

### Deliverables
_Examples:_
- _High-fi designs + dev specifications_
- _Interactive prototype (for testing)_
- _User testing and analysis of findings before implementation_

### Stakeholder(s)
_Who is directly involved? (developers, main points of contact, final approver)_

### Timeline
_Add completion date to ticket and any time specific notes here_

### Notes
_Add completion date to ticket and any time specific notes here_
